@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
-# pylint: disable-msg=f0401,w0613,w0631,w0622,w0122
 '''utilities for writing code that runs on Python 2 and 3'''
 
 import sys
 import types
 import operator
 try:
+    from __builtin__ import intern
     from future_builtins import filter, map, zip
+    from cPickle import loads as ld, dumps, HIGHEST_PROTOCOL
 except ImportError:
+    from sys import intern  # @UnusedImport
     from builtins import filter, map, zip  # @UnusedImport
+    from pickle import loads as ld, dumps, HIGHEST_PROTOCOL  # @UnusedImport
 try:
     import unittest2 as unittest
 except ImportError:
@@ -20,17 +23,6 @@ except ImportError:
         from dummy_thread import get_ident
     except ImportError:
         from _thread import get_ident  # @UnusedImport
-try:
-    from __builtin__ import intern
-except ImportError:
-    from sys import intern  # @UnusedImport
-try:
-    from cPickle import loads as ld, dumps, HIGHEST_PROTOCOL
-except ImportError:
-    from pickle import loads as ld, dumps, HIGHEST_PROTOCOL  # @UnusedImport
-
-__author__ = 'Benjamin Peterson <benjamin@python.org>'
-__version__ = '1.1.0'
 
 # True if we are running on Python 3.
 PY3 = sys.version_info[0] == 3
@@ -483,55 +475,3 @@ def tobytes(thing, encoding='utf-8', errors='strict'):
     return (
         texts(thing).encode(encoding, errors) if not isbinary(thing) else thing
     )
-
-try:
-    from functools import total_ordering  # @UnusedImport
-except ImportError:
-    def total_ordering(cls):
-        '''
-        class decorator that fills in missing ordering methods
-
-        not available for python versions < 2.7
-        '''
-        convert = {
-            '__lt__': [
-                ('__gt__', lambda self, other: not (
-                    self < other or self == other)),
-                ('__le__', lambda self, other: self < other or self == other),
-                ('__ge__', lambda self, other: not self < other),
-            ],
-            '__le__': [
-                ('__ge__',
-                lambda self, other: not self <= other or self == other),
-                ('__lt__',
-                lambda self, other: self <= other and not self == other),
-                ('__gt__', lambda self, other: not self <= other),
-            ],
-            '__gt__': [
-                ('__lt__', lambda self, other: not (
-                    self > other or self == other)),
-                ('__ge__', lambda self, other: self > other or self == other),
-                ('__le__', lambda self, other: not self > other),
-            ],
-            '__ge__': [
-                ('__le__', lambda self, other: (
-                    not self >= other) or self == other
-                ),
-                ('__gt__',
-                lambda self, other: self >= other and not self == other),
-                ('__lt__', lambda self, other: not self >= other)
-            ]
-        }
-        roots = set(dir(cls)) & set(convert)
-        if not roots:
-            raise ValueError(
-                'must define at least one ordering operation: < > <= >='
-            )
-        # prefer __lt__ to __le__ to __gt__ to __ge__
-        root = max(roots)
-        for opname, opfunc in convert[root]:
-            if opname not in roots:
-                opfunc.__name__ = opname
-                opfunc.__doc__ = getattr(int, opname).__doc__
-                setattr(cls, opname, opfunc)
-        return cls
